@@ -116,8 +116,7 @@ cong_app_private_insert_element_init (CongApp *app);
 /**
  * cong_app_singleton:
  *
- * TODO: Write me
- * Returns:
+ * Returns: the singleton instance of CongApp
  */
 CongApp*
 cong_app_singleton (void)
@@ -132,7 +131,7 @@ cong_app_singleton (void)
  * @argc:
  * @argv:
  *
- * TODO: Write me
+ * Construct the singleton instance of CongApp
  */
 void
 cong_app_construct_singleton (int   argc,
@@ -368,7 +367,7 @@ convert_text_html (guchar *data,
 	return convert_ucs2_to_utf8 (data, length);
 #else
 	/* Assume that it's valid UTF-8 HTML: */
-	return g_strndup (data, length);
+	return g_strndup ((gchar*)data, length);
 #endif
 }
 
@@ -559,7 +558,7 @@ cong_app_get_clipboard_xml_source (CongApp *app,
 			
 			if (selection_data) {
 				/* Parse, potentially convert to another XML format, then output in the desired form: */
-				xmlDocPtr xml_doc = xmlParseMemory (selection_data->data,
+				xmlDocPtr xml_doc = xmlParseMemory ((const char*)selection_data->data,
 								    selection_data->length);
 
 				gtk_selection_data_free (selection_data);
@@ -669,7 +668,7 @@ clipboard_get_cb (GtkClipboard *clipboard,
 		gtk_selection_data_set (selection_data,
 					gdk_atom_intern ("text/xml", FALSE),
 					8,
-					cong_selection->utf8_xml_buffer,
+					(const guchar*)cong_selection->utf8_xml_buffer,
 					strlen (cong_selection->utf8_xml_buffer));
 		break;
 	}
@@ -685,7 +684,7 @@ static gchar*
 generate_xml_for_selection (const gchar* xml_fragment,
 			    CongDocument *source_doc)
 {
-	const CongXMLChar* dtd_public_identifier;
+	const gchar *dtd_public_identifier;
 
 	g_assert (xml_fragment);
 	g_assert (IS_CONG_DOCUMENT (source_doc));
@@ -735,7 +734,7 @@ generate_text_for_selection (CongApp *app,
 				g_assert (xml_doc_result->children == xml_doc_result->last);
 				g_assert (xml_doc_result->children->type == XML_TEXT_NODE);
 
-				result = g_strdup (xml_doc_result->children->content);		
+				result = g_strdup ((gchar*)xml_doc_result->children->content);		
 			} else {
 				result = g_strdup ("");
 			}
@@ -949,6 +948,29 @@ cong_app_get_language_list (CongApp *app)
 	return PRIVATE(app)->language_list;
 }
 
+int unit_test = FALSE;
+
+const struct poptOption options[] = {
+	{
+		"unit-test",
+		'\0',
+		POPT_ARG_NONE,
+		&unit_test,
+		0,
+		N_("Unit test: quit immediately (after loading any files specified on the command-line)"),
+		NULL
+	},
+	{
+		NULL,
+		'\0',
+		0,
+		NULL,
+		0,
+		NULL,
+		NULL
+	}
+};
+
 static gboolean
 handle_cmdline_args (gpointer data)
 {
@@ -970,6 +992,11 @@ handle_cmdline_args (gpointer data)
 	
 	poptFreeContext (ctx);
 
+	/* Quit immediately after load, for a unit test: */
+	if (unit_test) {
+		gtk_main_quit ();
+	}
+
 	return FALSE;
 }
 
@@ -991,10 +1018,10 @@ cong_app_new (int   argc,
 	PRIVATE(app)->gnome_program = gnome_program_init (PACKAGE_NAME, PACKAGE_VERSION,
 							  LIBGNOMEUI_MODULE,
 							  argc,argv,
-							  GNOME_PARAM_HUMAN_READABLE_NAME,
-							  _("XML Editor"),
+							  GNOME_PARAM_HUMAN_READABLE_NAME, _("XML Editor"),
+							  GNOME_PARAM_POPT_TABLE, options,
 							  GNOME_PROGRAM_STANDARD_PROPERTIES,
-							  NULL);
+							  GNOME_PARAM_NONE);
 
 	g_value_init (&value, G_TYPE_POINTER);
 	g_object_get_property (G_OBJECT (PRIVATE (app)->gnome_program), GNOME_PARAM_POPT_CONTEXT,
@@ -1035,7 +1062,7 @@ cong_app_new (int   argc,
 								    FALSE,
 								    NULL);
 
-		PRIVATE (app)->xsl_selection_to_text = xsltParseStylesheetFile (stylesheet_file);
+		PRIVATE (app)->xsl_selection_to_text = xsltParseStylesheetFile ((const xmlChar*)stylesheet_file);
 		if (PRIVATE (app)->xsl_selection_to_text==NULL) {
 			g_warning ("Couldn't parse stylesheet %s", stylesheet_file);
 		}
