@@ -113,12 +113,17 @@ cong_command_construct (CongCommand *command,
 
 /**
  * cong_command_private_new:
- * @doc:
- * @description:
- * @consolidation_id:
+ * @doc: The #CongDocument upon which the command is to act.
+ * @description: Human-readable, translated name for this command, as it will appear in the undo/redo history
+ * widget
+ * @consolidation_id: A string ID (or NULL) for this command to allow multiple similar commands to be consolidated into 
+ * a single command.  For example, multiple characters being typed at the keboard can be merged into a single "Typing" command.
+ * 
+ * Should only be called by the internals of #CongDocument; if you wish to create a #CongCommand you should call cong_document_begin_command()
+ * instead.
+ *
+ * Returns:  the new #CongCommand
  *
- * TODO: Write me
- * Returns:
  */
 CongCommand*
 cong_command_private_new (CongDocument *doc,
@@ -148,10 +153,9 @@ cong_command_get_document (CongCommand *command)
 
 /**
  * cong_command_get_description:
- * @command:
+ * @command: a command
  *
- * TODO: Write me
- * Returns:
+ * Returns: the human-readable description of this command
  */
 const gchar*
 cong_command_get_description (CongCommand *command)
@@ -163,10 +167,11 @@ cong_command_get_description (CongCommand *command)
 
 /**
  * cong_command_get_consolidation_id:
- * @command:
+ * @command:  The relevant #CongCommand 
  *
- * TODO: Write me
- * Returns:
+ * Gets the ID (or NULL) of the command used for consolidating multiple similar operations into a single entry in the undo/redo history
+ *
+ * Returns: a constant string, or NULL if no merging is to occur
  */
 const gchar*
 cong_command_get_consolidation_id (CongCommand *command)
@@ -178,9 +183,9 @@ cong_command_get_consolidation_id (CongCommand *command)
 
 /**
  * cong_command_undo:
- * @command:
+ * @command: a command
  *
- * TODO: Write me
+ * Undoes the command.  All modifications contained within the command are undone from the document (in reverse order), the document's "is-modified" flag is set to whatever it was when the command was created.
  */
 void
 cong_command_undo (CongCommand *command)
@@ -190,7 +195,7 @@ cong_command_undo (CongCommand *command)
 
 	g_return_if_fail (IS_CONG_COMMAND(command));
 
-	g_message ("cong_command_undo(\"%s\")", cong_command_get_description(command));
+	/* g_message ("cong_command_undo(\"%s\")", cong_command_get_description(command)); */
 
 	PRIVATE(command)->has_ever_been_undone = TRUE;
 
@@ -222,7 +227,7 @@ cong_command_undo (CongCommand *command)
  * cong_command_redo:
  * @command:
  *
- * TODO: Write me
+ * Redoes a command that has previously been undone.  Replays all the modifications on the document in order from start to finish.
  */
 void
 cong_command_redo (CongCommand *command)
@@ -232,7 +237,7 @@ cong_command_redo (CongCommand *command)
 
 	g_return_if_fail (IS_CONG_COMMAND(command));
 
-	g_message ("cong_command_redo(\"%s\")", cong_command_get_description(command));
+	/* g_message ("cong_command_redo(\"%s\")", cong_command_get_description(command)); */
 
 	doc = cong_command_get_document (command);
 
@@ -256,11 +261,12 @@ cong_command_redo (CongCommand *command)
 }
 
 /**
- * cong_command_merge:
- * @dst:
- * @src:
+ * cong_command_merge: *
+ * @dst: The #CongCommand into which the modifications are to be added
+ * @src: The #CongCommand from which the modifications are to be taken
+ *
+ * Takes all of the modifications from @src and places them on the end of @dst.  Only to be used by the internals of the undo/redo management
  *
- * TODO: Write me
  */
 void
 cong_command_merge (CongCommand *dst,
@@ -275,7 +281,16 @@ cong_command_merge (CongCommand *dst,
 	PRIVATE(src)->list_of_modification = NULL;
 }
 
-
+/**
+ * cong_command_has_ever_been_undone: *
+ * @cmd:
+ *
+ * A function used by the command consolidation/merging system.  If you undo then redo a command,
+ * further similar operations should get separate entries in the undo/redo histroy, rather than being
+ * merged.
+ *
+ * Returns: A #gboolean, answering the question "has this command ever been undone?"
+ */
 gboolean
 cong_command_has_ever_been_undone (CongCommand *cmd)
 {
@@ -422,7 +437,7 @@ cong_command_add_node_set_parent (CongCommand *cmd,
 void 
 cong_command_add_node_set_text (CongCommand *cmd, 
 				CongNodePtr node, 
-				const xmlChar *new_content)
+				const gchar *new_content)
 {
 	CongModification *modification;
 	
@@ -450,8 +465,8 @@ void
 cong_command_add_node_set_attribute (CongCommand *cmd, 
 				     CongNodePtr node, 
 				     xmlNs *ns_ptr,
-				     const xmlChar *name, 
-				     const xmlChar *value)
+				     const gchar *name, 
+				     const gchar *value)
 {
 	CongModification *modification;
 	
@@ -480,7 +495,7 @@ void
 cong_command_add_node_remove_attribute (CongCommand *cmd, 
 					CongNodePtr node, 
 					xmlNs *ns_ptr,
-					const xmlChar *name)
+					const gchar *name)
 {
 	CongModification *modification;
 	
@@ -812,9 +827,11 @@ recursive_node_deletion_update_location_callback (CongDocument *doc,
 /**
  * cong_command_add_delete_range:
  * @cmd:
- * @range:
+ * @range: a range within the document; both start and end must have the same parent, so that proper nesting is maintained
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ *
+ * Deletes the given range within the document (can include multiple nodes).  Updates cursor and selection accordingly.
  */
 void 
 cong_command_add_delete_range (CongCommand *cmd,
@@ -924,7 +941,7 @@ cong_command_add_delete_range (CongCommand *cmd,
 			} else {
 			
 				/* Split up textual content of node: */
-				gchar *text_before = g_strndup (loc0.node->content, loc0.byte_offset);
+				gchar *text_before = g_strndup ((gchar*)loc0.node->content, loc0.byte_offset);
 
 				gchar *new_text = g_strdup_printf("%s%s",text_before, loc1.node->content + loc1.byte_offset);
 
@@ -964,7 +981,9 @@ cong_command_add_delete_range (CongCommand *cmd,
  * cong_command_add_delete_selection:
  * @cmd:
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ *
+ * Deletes the current selection within the document, updating cursor and selection accordingly.
  */
 void 
 cong_command_add_delete_selection (CongCommand *cmd)
@@ -994,9 +1013,11 @@ cong_command_add_delete_selection (CongCommand *cmd)
 /**
  * cong_command_add_insert_text_at_cursor:
  * @cmd:
- * @string:
+ * @string: a UTF-8 string
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ *
+ * Inserts the given text at the cursor, moving the cursor to the end of the inserted text.
  */
 void 
 cong_command_add_insert_text_at_cursor (CongCommand *cmd, 
@@ -1006,7 +1027,8 @@ cong_command_add_insert_text_at_cursor (CongCommand *cmd,
 	CongCursor *curs;
 	CongLocation old_cursor_loc;
 	CongLocation new_cursor_loc;
-	xmlChar *new_content;
+	gchar *initial_part;
+	gchar *new_content;
 	int byte_length;
 
 	g_return_if_fail (IS_CONG_COMMAND (cmd));
@@ -1029,23 +1051,25 @@ cong_command_add_insert_text_at_cursor (CongCommand *cmd,
 
 	byte_length = strlen(string);
 
-	new_content = xmlStrndup(old_cursor_loc.node->content, old_cursor_loc.byte_offset);
-	CONG_VALIDATE_UTF8(new_content);
+	initial_part = g_strndup ((const gchar*)old_cursor_loc.node->content, old_cursor_loc.byte_offset);
+	CONG_VALIDATE_UTF8(initial_part);
 
-	new_content = xmlStrcat(new_content, string);
-	CONG_VALIDATE_UTF8(new_content);
+	CONG_VALIDATE_UTF8((const gchar*)old_cursor_loc.node->content+old_cursor_loc.byte_offset);
 
-	CONG_VALIDATE_UTF8(old_cursor_loc.node->content+old_cursor_loc.byte_offset);
-	new_content = xmlStrcat(new_content, old_cursor_loc.node->content+old_cursor_loc.byte_offset);
+	new_content = g_strconcat (initial_part,
+				   string, 
+				   (const gchar*)old_cursor_loc.node->content+old_cursor_loc.byte_offset, 
+				   NULL);
 	CONG_VALIDATE_UTF8(new_content);
+	g_free (initial_part);
 
 	cong_command_add_node_set_text (cmd, 
 					old_cursor_loc.node,
 					new_content);
-	xmlFree(new_content);
+	g_free (new_content);
 
-	new_cursor_loc.byte_offset += byte_length;		
-	CONG_VALIDATE_UTF8(new_cursor_loc.node->content+new_cursor_loc.byte_offset);
+	new_cursor_loc.byte_offset += byte_length;
+	CONG_VALIDATE_UTF8((const gchar*)new_cursor_loc.node->content+new_cursor_loc.byte_offset);
 
 	cong_command_add_cursor_change (cmd,
 					&new_cursor_loc);
@@ -1150,10 +1174,10 @@ cong_command_add_xml_frag_data_nice_split2  (CongCommand *cmd,
 	} else if (len2==0) {
 		d = cong_node_new_textual (node_type, "", doc);
 	} else {
-		xmlChar* new_text = g_strndup(loc->node->content, len1); /* FIXME:  char type conversion? */
+		gchar* new_text = g_strndup((const gchar*)loc->node->content, len1);
 
 		/* Make split representation */
-		d = cong_node_new_textual_len (node_type, xml_frag_data_nice(loc->node) + len1, len2, doc); /* FIXME: check char ptr arithmetic; UTF8? */
+		d = cong_node_new_textual_len (node_type, cong_node_safe_get_content(loc->node) + len1, len2, doc); /* FIXME: check char ptr arithmetic; UTF8? */
 
 		/* Shrink original node */
 		cong_command_add_node_set_text(cmd, 
@@ -1196,7 +1220,7 @@ merge_text_update_location_callback (CongDocument *doc,
 
 	} else if (location->node == affected_node) {
 
-		location->byte_offset += strlen(affected_node->prev->content);
+		location->byte_offset += strlen((const char*)affected_node->prev->content);
 
 		return TRUE;
 	}
@@ -1242,7 +1266,9 @@ merge_adjacent_text_callback (CongDocument *doc,
  * cong_command_add_merge_adjacent_text_nodes:
  * @cmd:
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ * 
+ * Searches the entire document, looking for text nodes adjacent to other text nodes, merging them together.
  */
 void
 cong_command_add_merge_adjacent_text_nodes (CongCommand *cmd)
@@ -1265,7 +1291,9 @@ cong_command_add_merge_adjacent_text_nodes (CongCommand *cmd)
  * @cmd:
  * @node:
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ * 
+ * Searches direct children of the given node, looking for text nodes adjacent to other text nodes, merging them together.
  */
 void
 cong_command_add_merge_adjacent_text_children_of_node (CongCommand *cmd, 
@@ -1317,7 +1345,10 @@ cong_command_can_add_reparent_selection (CongCommand *cmd,
  * @cmd:
  * @node:
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ * 
+ * Splits the selected nodes as necessary and adds as a child of the input node
+ *
  * Returns:
  */
 CongNodePtr
@@ -1499,7 +1530,6 @@ split3_location_callback (CongDocument *doc,
 	return FALSE;
 }
 
-/* Splits a data node in 3 and returns pointer to the middle one */
 /**
  * cong_command_add_node_split3:
  * @cmd:
@@ -1507,8 +1537,11 @@ split3_location_callback (CongDocument *doc,
  * @c0:
  * @c1:
  *
- * TODO: Write me
- * Returns:
+ * Utility function to add a series of modifications to the given command.
+ *
+ * Splits a text or comment node into 3 nodes, and returns a pointer to the middle one
+ *
+ * Returns: the middle node of the three newly-created nodes
  */
 CongNodePtr
 cong_command_add_node_split3 (CongCommand *cmd, 
@@ -1539,9 +1572,9 @@ cong_command_add_node_split3 (CongCommand *cmd,
 	len3 = cong_node_get_length(node) - c1;
 
 	/* Make split representation */
-	d1 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node), len1, doc); /* FIXME:  audit the char types here, and the char pointer arithmetic. UTF8? */
-	d2 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node) + len1, len2, doc);
-	d3 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node) + len1 + len2, len3, doc);
+	d1 = cong_node_new_textual_len (node_type, cong_node_safe_get_content(node), len1, doc); /* FIXME:  audit the char types here, and the char pointer arithmetic. UTF8? */
+	d2 = cong_node_new_textual_len (node_type, cong_node_safe_get_content(node) + len1, len2, doc);
+	d3 = cong_node_new_textual_len (node_type, cong_node_safe_get_content(node) + len1 + len2, len3, doc);
 
 	cong_document_begin_edit(doc);
 
@@ -1580,9 +1613,11 @@ cong_command_add_node_split3 (CongCommand *cmd,
 /**
  * cong_command_add_remove_tag:
  * @cmd:
- * @node:
+ * @node: a node
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ *
+ * Removes the given node from the tree, moving all of its children into the space it occupied.
  */
 void 
 cong_command_add_remove_tag (CongCommand *cmd,
@@ -1651,12 +1686,14 @@ cong_command_add_set_cursor_to_first_text_descendant (CongCommand *cmd,
 
 /**
  * cong_command_add_set_external_dtd:
- * @cmd:
- * @root_element:
+ * @cmd: a command
+ * @root_element: the root element of the document
  * @public_id:
  * @system_id:
  *
- * TODO: Write me
+ * Utility function to add a series of modifications to the given command.
+ * 
+ * Sets an external DTD on the document, or removes it if NULL is given
  */
 void
 cong_command_add_set_external_dtd (CongCommand *cmd,
