@@ -52,13 +52,13 @@ static void
 cong_document_handle_node_set_parent(CongDocument *doc, CongNodePtr node, CongNodePtr adoptive_parent, gboolean add_to_end);
 
 static void
-cong_document_handle_node_set_text(CongDocument *doc, CongNodePtr node, const xmlChar *new_content);
+cong_document_handle_node_set_text(CongDocument *doc, CongNodePtr node, const gchar *new_content);
 
 static void
-cong_document_handle_node_set_attribute(CongDocument *doc, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name, const xmlChar *value);
+cong_document_handle_node_set_attribute(CongDocument *doc, CongNodePtr node, xmlNs *ns_ptr, const gchar *name, const gchar *value);
 
 static void
-cong_document_handle_node_remove_attribute(CongDocument *doc, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name);
+cong_document_handle_node_remove_attribute(CongDocument *doc, CongNodePtr node, xmlNs *ns_ptr, const gchar *name);
 
 static void
 cong_document_handle_selection_change(CongDocument *doc);
@@ -709,7 +709,7 @@ cong_document_get_parent_uri(CongDocument *doc)
  * TODO: Write me
  * Returns:
  */
-const CongXMLChar*
+const gchar*
 cong_document_get_dtd_public_identifier(CongDocument *doc)
 {
 	g_return_val_if_fail(doc, NULL);
@@ -720,7 +720,7 @@ cong_document_get_dtd_public_identifier(CongDocument *doc)
 		return NULL;
 	}
 
-	return PRIVATE(doc)->xml_doc->extSubset->ExternalID;
+	return (const gchar*)PRIVATE(doc)->xml_doc->extSubset->ExternalID;
 }
 
 /**
@@ -743,7 +743,7 @@ cong_document_get_xml_ns (CongDocument *doc,
 
 	ns = xmlSearchNsByHref (PRIVATE(doc)->xml_doc,
 				(xmlNodePtr)PRIVATE(doc)->xml_doc, /* FIXME: is this correct? */
-				ns_uri);
+				(const xmlChar*)ns_uri);
 
 	return ns;
 }
@@ -958,7 +958,7 @@ cong_document_get_node_name (CongDocument *doc,
 		{
 			#define TRUNCATION_LENGTH 15
 
-			gchar *content_header = cong_util_text_header (node->content, TRUNCATION_LENGTH);
+			gchar *content_header = cong_util_text_header ((const gchar*)node->content, TRUNCATION_LENGTH);
 			gchar *result = g_strdup_printf( _("Text \"%s\""), content_header);
 			g_free (content_header);
 			return result;
@@ -978,7 +978,7 @@ cong_document_get_node_name (CongDocument *doc,
 
 	case CONG_NODE_TYPE_COMMENT:
 		{
-			gchar *content_header = cong_util_text_header (node->content, TRUNCATION_LENGTH);
+			gchar *content_header = cong_util_text_header ((const gchar*)node->content, TRUNCATION_LENGTH);
 			gchar *result = g_strdup_printf( _("Comment \"%s\""), content_header);
 			g_free (content_header);
 			return result;
@@ -1463,7 +1463,7 @@ cong_document_private_node_set_parent (CongDocument *doc,
  * TODO: Write me
  */
 void 
-cong_document_private_node_set_text(CongDocument *doc, CongNodePtr node, const xmlChar *new_content)
+cong_document_private_node_set_text(CongDocument *doc, CongNodePtr node, const gchar *new_content)
 {
 	g_return_if_fail(doc);
 	g_return_if_fail(node);
@@ -1496,8 +1496,8 @@ void
 cong_document_private_node_set_attribute(CongDocument *doc, 
 					 CongNodePtr node, 
 					 xmlNs *ns_ptr,
-					 const xmlChar *name, 
-					 const xmlChar *value)
+					 const gchar *name, 
+					 const gchar *value)
 {
 	g_return_if_fail(doc);
 	g_return_if_fail(node);
@@ -1532,7 +1532,7 @@ void
 cong_document_private_node_remove_attribute(CongDocument *doc, 
 					    CongNodePtr node, 
 					    xmlNs *ns_ptr,
-					    const xmlChar *name)
+					    const gchar *name)
 {
 	g_return_if_fail(doc);
 	g_return_if_fail(node);
@@ -1769,9 +1769,9 @@ cong_document_get_language_for_node(CongDocument *doc,
 		while (node != NULL) {
 			
 			if (cong_node_type (node)==CONG_NODE_TYPE_ELEMENT) {
-				xmlChar *lang = xmlGetProp (node, "lang");
+				xmlChar *lang = xmlGetProp (node, (const xmlChar*)"lang");
 				if (lang != NULL) {
-					PangoLanguage *result = pango_language_from_string (lang);		
+					PangoLanguage *result = pango_language_from_string ((const gchar*)lang);
 					xmlFree (lang);
 					
 					return result;
@@ -1788,7 +1788,7 @@ cong_document_get_language_for_node(CongDocument *doc,
 		xmlChar *xml_lang = xmlNodeGetLang (node);
 
 		if (xml_lang) {
-			PangoLanguage *result = pango_language_from_string (xml_lang);		
+			PangoLanguage *result = pango_language_from_string ((const gchar*)xml_lang);		
 			xmlFree (xml_lang);
 			
 			return result;
@@ -1825,12 +1825,12 @@ cong_document_make_pango_log_attr_for_node (CongDocument *doc,
 
 	language = cong_document_get_language_for_node (doc, node);
 
-	*attrs_len = g_utf8_strlen (node->content,-1)+1;
+	*attrs_len = g_utf8_strlen ((const gchar*)node->content,-1)+1;
 
 	*pango_log_attrs = g_new (PangoLogAttr, (*attrs_len));
 	
-	pango_get_log_attrs (node->content,
-			     strlen(node->content), /* length in bytes */
+	pango_get_log_attrs ((const gchar*)node->content,
+			     strlen((const char*)node->content), /* length in bytes */
 			     -1,
 			     language,
 			     *pango_log_attrs,
@@ -1926,12 +1926,19 @@ cong_document_for_each_node_recurse (CongDocument *doc,
 
 /**
  * cong_document_for_each_node:
- * @doc:
- * @callback:
- * @callback_data:
+ * @doc: the document
+ * @callback: a callback to be invoked for every node in the document
+ * @callback_data: data for the callback
  *
- * TODO: Write me
- * Returns:
+ * Perform a depth-first traversal of the nodes in the DOM tree of this document, calling the supplied callback for each node,
+ * passing it the supplied data.  
+ * 
+ * If the callback returns TRUE, then traversal is halted: you can use this to test for the presence of a node satisfying some condition
+ * Otherwise, traversal continues.   If you wish to perform some operation on every node in the tree, your callback should always return FALSE.
+ * 
+ * Entity declarations are only visited once; it does not traverse below an entity reference, to avoid potential infinite loops.
+ *
+ * Returns:  TRUE if one of the callback calls returned TRUE (stopping the traversal prematurely); FALSE if the full traversal occurred
  */
 gboolean
 cong_document_for_each_node (CongDocument *doc, 
@@ -1950,13 +1957,18 @@ cong_document_for_each_node (CongDocument *doc,
 
 /**
  * cong_document_for_each_child_of_node:
- * @doc:
- * @parent:
- * @callback:
- * @callback_data:
+ * @doc: the document
+ * @parent: a node in the document
+ * @callback: a callback to be invoked for every direct descendent of the given node
+ * @callback_data: data for the callback
  *
- * TODO: Write me
- * Returns:
+ * Visit each of the direct descendents of the given node, calling the supplied callback for each,
+ * passing it the supplied data.  
+ * 
+ * If the callback returns TRUE, then traversal is halted: you can use this to test for the presence of a node satisfying some condition
+ * Otherwise, traversal continues.   If you wish to perform some operation on every child node, your callback should always return FALSE.
+ * 
+ * Returns:  TRUE if one of the callback calls returned TRUE (stopping the traversal prematurely); FALSE if the full traversal occurred
  */
 gboolean
 cong_document_for_each_child_of_node (CongDocument *doc, 
@@ -1981,11 +1993,13 @@ cong_document_for_each_child_of_node (CongDocument *doc,
 
 /**
  * cong_document_make_nodes_from_source_fragment:
- * @doc:
- * @source_fragment:
+ * @doc: the document for which the nodes are to be created
+ * @source_fragment: a fragment of well-formed XML source
  *
- * TODO: Write me
- * Returns:
+ * Tries to parse the source fragment, placing it inside a &lt;placeholder&gt; element
+ *
+ * Returns: a pointer to the &lt;placeholder&gt; element (with a miniature DOM tree below it corresponding to the XML source), or NULL if a parse error occurred.
+ * The "document" of these nodes is set up correctly, but they are not linked into the DOM tree.
  */
 CongNodePtr
 cong_document_make_nodes_from_source_fragment (CongDocument *doc, 
@@ -2299,9 +2313,9 @@ callback_can_export (CongServiceExporter *exporter,
 
 /**
  * cong_document_can_export:
- * @doc:
+ * @doc: a document
  *
- * Returns: TRUE if there are any exporters registered for the document.
+ * Returns: TRUE iff a plugin is available that knows how to export the document.
  */
 gboolean
 cong_document_can_export (CongDocument *doc)
@@ -2338,9 +2352,9 @@ callback_can_print (CongServicePrintMethod *print_method,
 
 /**
  * cong_document_can_print:
- * @doc:
+ * @doc: a document
  *
- * Returns:
+ * Returns: TRUE iff a plugin is available that knows how to print the given document
  */
 gboolean
 cong_document_can_print (CongDocument *doc)
@@ -2376,7 +2390,7 @@ cong_document_dispose (GObject *object)
 {
 	CongDocument *doc = CONG_DOCUMENT (object);
 
-	g_message ("cong_document_dispose");
+	/* g_message ("cong_document_dispose"); */
 
 	g_assert (doc->private);
 	g_assert (PRIVATE(doc)->views == NULL); /* There must not be any views left referencing this document; views are supposed to hold references to the doc */
@@ -2710,7 +2724,7 @@ cong_document_handle_node_set_parent(CongDocument *doc, CongNodePtr node, CongNo
 }
 
 static void
-cong_document_handle_node_set_text(CongDocument *doc, CongNodePtr node, const xmlChar *new_content)
+cong_document_handle_node_set_text(CongDocument *doc, CongNodePtr node, const gchar *new_content)
 {
 	GList *iter;
 
@@ -2752,8 +2766,8 @@ static void
 cong_document_handle_node_set_attribute(CongDocument *doc, 
 					CongNodePtr node, 
 					xmlNs *ns_ptr,
-					const xmlChar *name, 
-					const xmlChar *value)
+					const gchar *name, 
+					const gchar *value)
 {
 	GList *iter;
 
@@ -2806,7 +2820,7 @@ static void
 cong_document_handle_node_remove_attribute(CongDocument *doc, 
 					   CongNodePtr node, 
 					   xmlNs *ns_ptr,
-					   const xmlChar *name)
+					   const gchar *name)
 {
 	GList *iter;
 
