@@ -95,7 +95,7 @@ get_flow_type (CongEditorNode *editor_node);
 static void 
 on_signal_set_text_notify_after (CongDocument *doc, 
 				 CongNodePtr node, 
-				 const xmlChar *new_content, 
+				 const gchar *new_content, 
 				 gpointer user_data);
 
 static void 
@@ -687,7 +687,7 @@ cong_selection_get_end_byte_offset (CongSelection *selection,
 			if (cong_node_get_ordering (start_loc->node, node)<0) {
 				/* Then this node is within a larger selection: */
 				g_assert (node->content);
-				*output = strlen (node->content);
+				*output = strlen ((const char*)node->content);
 				return TRUE;
 			}
 		}		
@@ -703,7 +703,7 @@ cong_selection_get_end_byte_offset (CongSelection *selection,
 static void 
 on_signal_set_text_notify_after (CongDocument *doc, 
 				 CongNodePtr node, 
-				 const xmlChar *new_content, 
+				 const gchar *new_content, 
 				 gpointer user_data)
 {
 	CongEditorNodeText *editor_node_text = (CongEditorNodeText*)user_data;
@@ -801,7 +801,7 @@ get_location_at_xy(CongEditorNodeText *editor_node_text,
 						       &trailing)) {
 		int original_byte_offset;
 
-#if 1
+#if 0
 		g_message("(%i,%i) -> index %i", x,y, index_);
 #endif
 
@@ -860,29 +860,42 @@ on_signal_button_press (CongEditorArea *editor_area,
 		/* Main mouse button: "left" for most users */
 		switch (event->type) {
 		default: return FALSE; /* do nothing */
-#if 0
+
 		case GDK_3BUTTON_PRESS:
 			/* Handle triple-click by locating the tag containing the click location, 
 			   making that the selection, with the cursor at the end of it? */
 			{
 				CongLocation click_location;
-				CongLocation start_of_tag;
-				CongLocation end_of_tag;
+				CongLocation start_of_line;
+				CongLocation end_of_line;
 
-				if (get_location_at_xy(editor_node_text, editor_area_text_fragment, event->x, event->y, &click_location)) {
-					cong_location_calc_tag_start(&click_location, &tag_start);
-					cong_location_calc_tag_end(&click_location, &tag_end);
-						
-					cong_location_copy(&selection->loc0, &start_of_tag);
-					cong_location_copy(&selection->loc1, &end_of_tag);
-					cong_location_copy(&cursor->location, &end_of_tag);
-				
-					cong_document_on_selection_change(doc);
-					cong_document_on_cursor_change(doc);
+				if (get_location_at_xy(editor_node_text,
+					    editor_area_text_fragment,
+					    event->x, event->y,
+					    &click_location))
+			       	{
+					CongCommand *cmd;
+					cong_location_calc_line_start(
+						&click_location,
+						doc,
+						&start_of_line);
+					cong_location_calc_line_end(
+						&click_location,
+						doc,
+						&end_of_line);
+					cmd = cong_document_begin_command(doc,
+						_("Select line"),
+						NULL);
+					cong_command_add_selection_change(cmd,
+						&start_of_line,
+						&end_of_line);
+					cong_command_add_cursor_change(cmd,
+						&end_of_line);
+
+					cong_document_end_command(doc, cmd);
 				}
 			}
 			return TRUE;
-#endif
 
 		case GDK_2BUTTON_PRESS:
 			/* Handle double-click by locating the word containing the click location, 
@@ -1034,7 +1047,7 @@ get_flow_type(CongEditorNode *editor_node)
 static const gchar*
 get_text_cache_input_text (CongEditorNodeText *editor_node_text)
 {
-	return cong_editor_node_get_node (CONG_EDITOR_NODE(editor_node_text))->content;
+	return (const gchar*)cong_editor_node_get_node (CONG_EDITOR_NODE(editor_node_text))->content;
 }
 
 static PangoAttrList*
@@ -1085,12 +1098,12 @@ get_text_cache_input_attributes (CongEditorNodeText *editor_node_text)
 				add_attrs_for_state (attr_list, selection_start, selection_end, select_state);
 				add_attrs_for_state (attr_list, selection_end, strlen(text), FRAG_NORMAL);
 				
-				g_message ("\"%s\" got sel start and end [%i,%i)", text, selection_start, selection_end);
+				/* g_message ("\"%s\" got sel start and end [%i,%i)", text, selection_start, selection_end); */
 			} else {
 				/* we've got a selection that starts in this node but carries on past the end: */
 				add_attrs_for_state (attr_list, selection_start, strlen(text), select_state);
 
-				g_message ("\"%s\" got sel start %i", text, selection_start);
+				/* g_message ("\"%s\" got sel start %i", text, selection_start); */
 			}
 		} else {
 
@@ -1099,7 +1112,7 @@ get_text_cache_input_attributes (CongEditorNodeText *editor_node_text)
 				add_attrs_for_state (attr_list, 0, selection_end, select_state);
 				add_attrs_for_state (attr_list, selection_end, strlen(text), FRAG_NORMAL);
 
-				g_message ("\"%s\" got sel end %i", text, selection_end);
+				/* g_message ("\"%s\" got sel end %i", text, selection_end); */
 
 			} else {
 				/* no selections present: */
@@ -1120,12 +1133,12 @@ get_text_cache_input_attributes (CongEditorNodeText *editor_node_text)
 										this_node);
 
 				list_of_words = cong_util_get_words (language,
-								     this_node->content);
+								     (const gchar*)this_node->content);
 				for (iter = list_of_words; iter; iter=iter->next) {
 					CongWord *word = (CongWord*)iter->data;
 
 					if (cong_util_spellcheck_word (language,
-								       this_node->content,
+								       (const gchar*)this_node->content,
 								       word)) {
 						add_attrs_for_error (attr_list,
 								     word->start_byte_offset,
