@@ -28,6 +28,7 @@
 
 #include "cong-app.h"
 #include "cong-eel.h"
+#include "cong-util.h"
 
 #include <gtk/gtkdrawingarea.h>
 
@@ -46,7 +47,7 @@
 #include "cong-ui-hooks.h"
 
 #define SHOW_CURSOR_SPEW 0
-#define DEBUG_IM_CONTEXT 1
+#define DEBUG_IM_CONTEXT 0
 
 /* 
    The CongEditorWidget3 maintains a hash table from CongTraversalNodes to CongEditorNodes.
@@ -380,8 +381,8 @@ cong_editor_widget3_construct (CongEditorWidget3 *editor_widget,
 
 	gtk_widget_set_events(GTK_WIDGET(editor_widget), GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK | GDK_KEY_PRESS_MASK);
 
-	gtk_widget_set(GTK_WIDGET(editor_widget), "can_focus", (gboolean) TRUE, 0);
-	gtk_widget_set(GTK_WIDGET(editor_widget), "can_default", (gboolean) TRUE, 0);
+	gtk_widget_set(GTK_WIDGET(editor_widget), "can_focus", (gboolean) TRUE, NULL);
+	gtk_widget_set(GTK_WIDGET(editor_widget), "can_default", (gboolean) TRUE, NULL);
 
 	/* Set up GTK Input Method support: */
 	{
@@ -823,7 +824,7 @@ cong_editor_widget3_finalize (GObject *object)
 {
 	CongEditorWidget3 *editor_widget = CONG_EDITOR_WIDGET3 (object);
 
-	g_message ("cong_editor_widget3_finalize");
+	/* g_message ("cong_editor_widget3_finalize"); */
 
 	g_object_unref (G_OBJECT (PRIVATE(editor_widget)->im_context));
 	
@@ -838,7 +839,7 @@ cong_editor_widget3_dispose (GObject *object)
 {
 	CongEditorWidget3 *editor_widget = CONG_EDITOR_WIDGET3 (object);
 
-	g_message ("cong_editor_widget3_dispose");
+	/* g_message ("cong_editor_widget3_dispose"); */
 
 	g_assert (editor_widget->private);
 
@@ -1797,3 +1798,56 @@ cong_editor_widget_get_primary_window(CongEditorWidget3 *editor_widget)
 {
 	return PRIVATE(editor_widget)->primary_window;
 }
+
+struct add_editor_node_cb_data
+{
+	xmlDocPtr xml_doc;
+	xmlNodePtr parent_xml_node;
+};
+
+static gboolean
+recursively_add_editor_area (CongEditorArea *editor_area, gpointer user_data)
+{
+	xmlNodePtr xml_node;
+	struct add_editor_node_cb_data *cb_data = (struct add_editor_node_cb_data *)user_data;
+	struct add_editor_node_cb_data child_cb_data;
+
+	g_assert (editor_area);
+	g_assert (cb_data);
+	g_assert (cb_data->xml_doc);
+	g_assert (cb_data->parent_xml_node);
+
+	xml_node = cong_editor_area_make_debug_xml_element (editor_area, cb_data->xml_doc);
+	xmlAddChild(cb_data->parent_xml_node, xml_node);
+
+	child_cb_data.xml_doc = cb_data->xml_doc;
+	child_cb_data.parent_xml_node = xml_node;
+
+	cong_editor_area_for_all (editor_area,
+				  recursively_add_editor_area,
+				  &child_cb_data);
+
+	return FALSE;
+}
+
+xmlDocPtr
+cong_editor_widget_debug_dump_area_tree (CongEditorWidget3 *editor_widget)
+{
+	xmlDocPtr xml_doc;
+	xmlNodePtr xml_node;
+	struct add_editor_node_cb_data cb_data;
+
+	g_return_val_if_fail (editor_widget, NULL);
+
+	xml_doc = cong_util_new_xml_doc ();
+	xml_node = cong_util_new_xml_element (xml_doc, "conglomerate-area-debug-dump-v0");
+	xmlDocSetRootElement(xml_doc,
+			     xml_node);	
+
+	cb_data.xml_doc = xml_doc;
+	cb_data.parent_xml_node = xml_node;
+
+	recursively_add_editor_area (PRIVATE(editor_widget)->root_area, &cb_data);	
+
+	return xml_doc;
+}
