@@ -151,6 +151,15 @@ save_document_as(CongDocument *doc, GtkWindow *parent_window)
 	        cong_document_save(doc, new_doc_name, parent_window);
 	}
 
+	/* Add recent entry */
+	{
+		CongPrimaryWindow *primary_window = cong_document_get_primary_window(doc);
+		EggRecentItem *item;
+
+		item = egg_recent_item_new_from_uri (new_doc_name);
+		egg_recent_item_add_group (item, "Conglomerate");
+		egg_recent_model_add_full (primary_window->recent_model, item);
+	}
 
 	g_free(new_doc_name);
 	gnome_vfs_uri_unref (uri);
