@@ -60,9 +60,9 @@ static void on_document_node_make_orphan(CongView *view, gboolean before_event,
 static void on_document_node_add_after(CongView *view, gboolean before_event, CongNodePtr node, CongNodePtr older_sibling);
 static void on_document_node_add_before(CongView *view, gboolean before_event, CongNodePtr node, CongNodePtr younger_sibling);
 static void on_document_node_set_parent(CongView *view, gboolean before_event, CongNodePtr node, CongNodePtr adoptive_parent, gboolean add_to_end);
-static void on_document_node_set_text(CongView *view, gboolean before_event, CongNodePtr node, const xmlChar *new_content);
-static void on_document_node_set_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name, const xmlChar *value);
-static void on_document_node_remove_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name);
+static void on_document_node_set_text(CongView *view, gboolean before_event, CongNodePtr node, const gchar *new_content);
+static void on_document_node_set_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const gchar *name, const gchar *value);
+static void on_document_node_remove_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const gchar *name);
 static void on_selection_change(CongView *view);
 static void on_cursor_change(CongView *view);
 static void on_document_set_dtd_ptr (CongView *view, 
@@ -107,7 +107,7 @@ regenerate_source (CongDocument *doc,
 #endif
 	
 	gtk_text_buffer_set_text (GTK_TEXT_BUFFER(text_buffer),
-				  doc_txt_ptr,
+				  (const gchar*)doc_txt_ptr,
 				  doc_txt_len);
 	
 	xmlFree (doc_txt_ptr);
@@ -231,7 +231,7 @@ static void on_document_node_set_parent(CongView *view, gboolean before_event, C
 	}
 }
 
-static void on_document_node_set_text(CongView *view, gboolean before_event, CongNodePtr node, const xmlChar *new_content)
+static void on_document_node_set_text(CongView *view, gboolean before_event, CongNodePtr node, const gchar *new_content)
 {
 	CongSourceView *source_view;
 
@@ -250,7 +250,7 @@ static void on_document_node_set_text(CongView *view, gboolean before_event, Con
 	}
 }
 
-static void on_document_node_set_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name, const xmlChar *value)
+static void on_document_node_set_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const gchar *name, const gchar *value)
 {
 	CongSourceView *source_view;
 
@@ -270,7 +270,7 @@ static void on_document_node_set_attribute(CongView *view, gboolean before_event
 	}
 }
 
-static void on_document_node_remove_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const xmlChar *name)
+static void on_document_node_remove_attribute(CongView *view, gboolean before_event, CongNodePtr node, xmlNs *ns_ptr, const gchar *name)
 {
 	CongSourceView *source_view;
 
