@@ -121,6 +121,9 @@ cong_ui_hook_tree_convert_to_comment (CongDocument *doc,
 void
 cong_ui_hook_tree_convert_from_comment (CongDocument *doc,
 					GtkWindow *parent_window);
+void
+cong_ui_hook_tree_convert_from_entity_ref_to_copy  (CongDocument *doc,
+						    GtkWindow *parent_window);
 
 /** Legacy UI Hooks without clean marshalling (to be cleanup up eventually): **/
 
@@ -175,6 +178,9 @@ cong_menus_setup_action_groups (CongPrimaryWindow *primary_window);
 guint
 cong_menus_setup_ui_layout (CongPrimaryWindow *primary_window);
 
+void
+cong_menus_setup_recent_files (CongPrimaryWindow *primary_window);
+
 #if 0
 guint
 cong_menus_create_items (CongPrimaryWindow *primary_window);
