@@ -163,7 +163,7 @@ factory_page_creation_callback_unified(CongServiceDocumentFactory *factory,
 /**
    Manufactures appropriate DocBook DTD, and assigns it to the given document, then adds it to the node tree (so it should show up when serialised)
  */
-static xmlDtdPtr add_docbook_declaration(xmlDocPtr xml_doc, const xmlChar *root_element)
+static xmlDtdPtr add_docbook_declaration(xmlDocPtr xml_doc, const gchar *root_element)
 {
 	xmlDtdPtr xml_dtd;
 
@@ -186,20 +186,20 @@ static xmlDtdPtr add_docbook_declaration(xmlDocPtr xml_doc, const xmlChar *root_
  * Returns:
  */
 xmlDocPtr 
-make_article(const xmlChar *title)
+make_article(const gchar *title)
 {
 	xmlDocPtr xml_doc;
 	xmlNodePtr root_node;
 	xmlNodePtr section_node;
 
 	/* Build up the document and its content: */
-	xml_doc = xmlNewDoc("1.0");
+	xml_doc = xmlNewDoc((const xmlChar*)"1.0");
 
 	add_docbook_declaration(xml_doc, "article");
 
 	root_node = xmlNewDocNode(xml_doc,
 				  NULL, /* xmlNsPtr ns, */
-				  "article",
+				  (const xmlChar*)"article",
 				  NULL);
 
 	xmlDocSetRootElement(xml_doc,
@@ -208,28 +208,28 @@ make_article(const xmlChar *title)
 	xmlAddChild(root_node,
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  title)
+				  (const xmlChar*)"title",
+				  (const xmlChar*)title)
 		    );
 
 	section_node = xmlNewDocNode(xml_doc,
 				     NULL,
-				     "section",
-				     "");
+				     (const xmlChar*)"section",
+				     (const xmlChar*)"");
 	xmlAddChild(root_node, section_node);
 
 	xmlAddChild(section_node, 
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  _("Untitled section"))
+				  (const xmlChar*)"title",
+				  (const xmlChar*)_("Untitled section"))
 		    );
 
 	xmlAddChild(section_node, 
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "para",
-				  _("Text of the article goes here"))
+				  (const xmlChar*)"para",
+				  (const xmlChar*)_("Text of the article goes here"))
 		    );
 
 	return xml_doc;
@@ -262,20 +262,20 @@ factory_action_callback_article(CongServiceDocumentFactory *factory, CongNewFile
  * Returns:
  */
 xmlDocPtr 
-make_book(const xmlChar *title)
+make_book(const gchar *title)
 {
 	xmlDocPtr xml_doc;
 	xmlNodePtr root_node;
 	xmlNodePtr chapter_node;
 
 	/* Build up the document and its content: */
-	xml_doc = xmlNewDoc("1.0");
+	xml_doc = xmlNewDoc((const xmlChar*)"1.0");
 
 	add_docbook_declaration(xml_doc, "book");	
 
 	root_node = xmlNewDocNode(xml_doc,
 				  NULL, /* xmlNsPtr ns, */
-				  "book",
+				  (const xmlChar*)"book",
 				  NULL);
 
 	xmlDocSetRootElement(xml_doc,
@@ -284,28 +284,28 @@ make_book(const xmlChar *title)
 	xmlAddChild(root_node,
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  title)
+				  (const xmlChar*)"title",
+				  (const xmlChar*)title)
 		    );
 
 	chapter_node = xmlNewDocNode(xml_doc,
 				     NULL,
-				     "chapter",
-				     "");
+				     (const xmlChar*)"chapter",
+				     (const xmlChar*)"");
 	xmlAddChild(root_node, chapter_node);
 
 	xmlAddChild(chapter_node, 
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  _("Untitled chapter"))
+				  (const xmlChar*)"title",
+				  (const xmlChar*)_("Untitled chapter"))
 		    );
 
 	xmlAddChild(chapter_node, 
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "para",
-				  _("Text of the first chapter goes here"))
+				  (const xmlChar*)"para",
+				  (const xmlChar*)_("Text of the first chapter goes here"))
 		    );
 
 	return xml_doc;
@@ -338,20 +338,20 @@ factory_action_callback_book(CongServiceDocumentFactory *factory, CongNewFileAss
  * Returns:
  */
 xmlDocPtr 
-make_set(const xmlChar *title)
+make_set(const gchar *title)
 {
 	xmlDocPtr xml_doc;
 	xmlNodePtr root_node;
 	xmlNodePtr book_node;
 
 	/* Build up the document and its content: */
-	xml_doc = xmlNewDoc("1.0");
+	xml_doc = xmlNewDoc((const xmlChar*)"1.0");
 
 	add_docbook_declaration(xml_doc, "set");	
 
 	root_node = xmlNewDocNode(xml_doc,
 				  NULL, /* xmlNsPtr ns, */
-				  "set",
+				  (const xmlChar*)"set",
 				  NULL);
 
 	xmlDocSetRootElement(xml_doc,
@@ -360,22 +360,22 @@ make_set(const xmlChar *title)
 	xmlAddChild(root_node,
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  title)
+				  (const xmlChar*)"title",
+				  (const xmlChar*)title)
 		    );
 
 	book_node = xmlNewDocNode(xml_doc,
 				     NULL,
-				     "book",
-				     "");
+				     (const xmlChar*)"book",
+				     (const xmlChar*)"");
 
 	xmlAddChild(root_node, book_node);
 
 	xmlAddChild(book_node, 
 		    xmlNewDocNode(xml_doc,
 				  NULL,
-				  "title",
-				  _("Untitled book"))
+				  (const xmlChar*)"title",
+				  (const xmlChar*)_("Untitled book"))
 		    );
 
 	return xml_doc;
@@ -941,14 +941,14 @@ text_importer_action_callback(CongServiceImporter *importer, const gchar *uri, c
 		g_assert(buffer);
 
 		/* Build up the document and its content: */
-		xml_doc = xmlNewDoc("1.0");
+		xml_doc = xmlNewDoc((const xmlChar*)"1.0");
 
 		add_docbook_declaration(xml_doc, "article");
 			
 		root_node = xmlNewDocNode(xml_doc,
 					  NULL, /* xmlNsPtr ns, */
-					  "article",
-					  NULL);
+					  (const xmlChar*)"article",
+					  (const xmlChar*)NULL);
 
 		xmlDocSetRootElement(xml_doc,
 				     root_node);
@@ -1018,11 +1018,11 @@ sourcecode_importer_action_callback(CongServiceImporter *importer, const gchar *
 		g_assert(buffer);
 
 		/* Build up the document and its content: */
-		xml_doc = xmlNewDoc("1.0");
+		xml_doc = xmlNewDoc((const xmlChar*)"1.0");
 			
 		root_node = xmlNewDocNode(xml_doc,
 					  NULL, /* xmlNsPtr ns, */
-					  "article",
+					  (const xmlChar*)"article",
 					  NULL);
 
 		xmlDocSetRootElement(xml_doc,
@@ -1031,15 +1031,15 @@ sourcecode_importer_action_callback(CongServiceImporter *importer, const gchar *
 		xmlAddChild(root_node,
 			    xmlNewDocNode(xml_doc,
 					  NULL,
-					  "title",
-					  uri)
+					  (const xmlChar*)"title",
+					  (const xmlChar*)uri)
 			    );
 
 		xmlAddChild(root_node,
 			    xmlNewDocNode(xml_doc,
 					  NULL,
-					  "programlisting",
-					  buffer)
+					  (const xmlChar*)"programlisting",
+					  (const xmlChar*)buffer)
 			    );
 
 		/* Finished building content: */
@@ -1433,8 +1433,293 @@ docbook_print_method_action_callback (CongServicePrintMethod *print_method,
 }
 #endif /* #if ENABLE_PRINTING */
 
+static void
+open_ulink_in_browser (CongNodePtr node)
+{
+	gchar *url = cong_node_get_attribute (node, NULL, "url");
+
+	if (url) {	
+		/* FIXME: should we have some error handling? */
+		gnome_url_show (url,
+				NULL);
+	}
+
+	g_free (url);
+}
+
+static void
+on_test_link_pressed (GtkButton *button,
+		      gpointer user_data)
+{
+	CongNodePtr node = user_data;
+
+	open_ulink_in_browser (node);
+}
+
+/* Property pages: */
 /**
- * docbook_generic_node_factory_method:
+ * docbook_orderedlist_page_factory_method:
+ * @custom_property_page:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+GtkWidget* 
+docbook_orderedlist_page_factory_method (CongServiceNodePropertyPage *custom_property_page,
+					 CongDocument *doc)
+{
+	gchar* glade_filename;
+	GladeXML *xml;
+#if 0
+	GtkWidget *notebook1;
+#endif
+
+	g_message("docbook_orderedlist_properties_page_factory_method");
+
+	g_return_val_if_fail (custom_property_page, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	glade_filename = gnome_program_locate_file (cong_app_get_gnome_program (cong_app_singleton()),
+						    GNOME_FILE_DOMAIN_APP_DATADIR,
+						    "conglomerate/glade/docbook-orderedlist-properties.glade",
+						    FALSE,
+						    NULL);
+
+	global_glade_doc_ptr = doc;
+#if 0
+	global_glade_node_ptr = node;
+#endif
+
+	xml = glade_xml_new(glade_filename, "orderedlist_page", NULL);
+	glade_xml_signal_autoconnect(xml);
+
+	global_glade_doc_ptr = NULL;
+	global_glade_node_ptr = NULL;
+
+	g_free(glade_filename);
+
+#if 0
+	/* Wire stuff up: */
+	{
+		/* The numeration radio buttons: */
+		cong_bind_radio_button (GTK_RADIO_BUTTON (glade_xml_get_widget(xml, "arabic")),
+					doc,
+					node,
+					NULL,
+					"numeration",
+					"arabic");
+		cong_bind_radio_button (GTK_RADIO_BUTTON (glade_xml_get_widget(xml, "loweralpha")),
+					doc,
+					node,
+					NULL,
+					"numeration",
+					"loweralpha");
+		cong_bind_radio_button (GTK_RADIO_BUTTON (glade_xml_get_widget(xml, "lowerroman")),
+					doc,
+					node,
+					NULL,
+					"numeration",
+					"lowerroman");
+		cong_bind_radio_button (GTK_RADIO_BUTTON (glade_xml_get_widget(xml, "upperalpha")),
+					doc,
+					node,
+					NULL,
+					"numeration",
+					"upperalpha");
+		cong_bind_radio_button (GTK_RADIO_BUTTON (glade_xml_get_widget(xml, "upperroman")),
+					doc,
+					node,
+					NULL,
+					"numeration",
+					"upperroman");
+		
+		/* The checkboxes: */
+		cong_bind_check_button (GTK_CHECK_BUTTON (glade_xml_get_widget(xml, "inheritnum")),
+					doc,
+					node,
+					NULL,
+					"inheritnum",
+					"ignore",
+					"inherit");
+		cong_bind_check_button (GTK_CHECK_BUTTON (glade_xml_get_widget(xml, "spacing")),
+					doc,
+					node,
+					NULL,
+					"spacing",
+					"normal",
+					"compact");
+		cong_bind_check_button (GTK_CHECK_BUTTON (glade_xml_get_widget(xml, "continuation")),
+					doc,
+					node,
+					NULL,
+					"continuation",
+					"restart",
+					"continues");
+		
+	}
+	
+	/* Add the advanced properties tab: */
+	notebook1 = glade_xml_get_widget(xml, "notebook1");
+	cong_ui_append_advanced_node_properties_page(GTK_NOTEBOOK(notebook1),
+						     doc, 
+						     node);
+#endif
+	
+	return glade_xml_get_widget (xml, "orderedlist_page");
+}
+
+/**
+ * docbook_ulink_page_factory_method:
+ * @custom_property_page:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+GtkWidget* 
+docbook_ulink_page_factory_method (CongServiceNodePropertyPage *custom_property_page,
+				   CongDocument *doc)
+{
+	gchar* glade_filename;
+	GladeXML *xml;
+
+	g_message("docbook_ulink_properties_page_factory_method");
+
+	g_return_val_if_fail(custom_property_page, NULL);
+	g_return_val_if_fail(doc, NULL);
+
+	glade_filename = gnome_program_locate_file (cong_app_get_gnome_program (cong_app_singleton()),
+						    GNOME_FILE_DOMAIN_APP_DATADIR,
+						    "conglomerate/glade/docbook-ulink-properties.glade",
+						    FALSE,
+						    NULL);
+	global_glade_doc_ptr = doc;
+#if 0
+	global_glade_node_ptr = node;
+#endif
+
+	xml = glade_xml_new(glade_filename, "ulink_page", NULL);
+	glade_xml_signal_autoconnect(xml);
+
+#if 0
+	g_signal_connect (G_OBJECT (glade_xml_get_widget(xml, "test_link_button")),
+			  "pressed",
+			  G_CALLBACK (on_test_link_pressed),
+			  node);
+#endif
+
+	global_glade_doc_ptr = NULL;
+	global_glade_node_ptr = NULL;
+
+	g_free(glade_filename);
+
+	return glade_xml_get_widget(xml, "ulink_page");
+}
+#if 1
+static GtkWidget* 
+docbook_node_page_factory_method_scope (CongServiceNodePropertyPage *custom_property_page, 
+					CongDocument *doc)
+{
+	gchar* glade_filename;
+	GladeXML *xml;
+
+	g_return_val_if_fail (custom_property_page, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	glade_filename = gnome_program_locate_file (cong_app_get_gnome_program (cong_app_singleton()),
+						    GNOME_FILE_DOMAIN_APP_DATADIR,
+						    "conglomerate/glade/docbook-common-properties.glade",
+						    FALSE,
+						    NULL);
+
+	global_glade_doc_ptr = doc;
+#if 0
+	global_glade_node_ptr = node;
+#endif
+
+	xml = glade_xml_new(glade_filename, "scope_page", NULL);
+	glade_xml_signal_autoconnect(xml);
+
+	global_glade_doc_ptr = NULL;
+	global_glade_node_ptr = NULL;
+
+	/* FIXME: wire stuff up! */
+	
+	g_free(glade_filename);
+	
+	return glade_xml_get_widget(xml, "scope_page");
+}
+static GtkWidget* 
+docbook_node_page_factory_method_language (CongServiceNodePropertyPage *custom_property_page, 
+					CongDocument *doc)
+{
+	gchar* glade_filename;
+	GladeXML *xml;
+
+	g_return_val_if_fail (custom_property_page, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	glade_filename = gnome_program_locate_file (cong_app_get_gnome_program (cong_app_singleton()),
+						    GNOME_FILE_DOMAIN_APP_DATADIR,
+						    "conglomerate/glade/docbook-common-properties.glade",
+						    FALSE,
+						    NULL);
+
+	global_glade_doc_ptr = doc;
+#if 0
+	global_glade_node_ptr = node;
+#endif
+
+	xml = glade_xml_new(glade_filename, "language_page", NULL);
+	glade_xml_signal_autoconnect(xml);
+
+	global_glade_doc_ptr = NULL;
+	global_glade_node_ptr = NULL;
+
+	/* FIXME: wire stuff up! */
+	
+	g_free(glade_filename);
+
+	return glade_xml_get_widget(xml, "language_page");
+}
+static GtkWidget* 
+docbook_node_page_factory_method_revisions (CongServiceNodePropertyPage *custom_property_page, 
+					CongDocument *doc)
+{
+	gchar* glade_filename;
+	GladeXML *xml;
+
+	g_return_val_if_fail (custom_property_page, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	glade_filename = gnome_program_locate_file (cong_app_get_gnome_program (cong_app_singleton()),
+						    GNOME_FILE_DOMAIN_APP_DATADIR,
+						    "conglomerate/glade/docbook-common-properties.glade",
+						    FALSE,
+						    NULL);
+
+	global_glade_doc_ptr = doc;
+#if 0
+	global_glade_node_ptr = node;
+#endif
+
+	xml = glade_xml_new(glade_filename, "revisions_page", NULL);
+	glade_xml_signal_autoconnect(xml);
+
+	global_glade_doc_ptr = NULL;
+	global_glade_node_ptr = NULL;
+
+	/* FIXME: wire stuff up! */
+	
+	g_free(glade_filename);
+
+	return glade_xml_get_widget(xml, "revisions_page");
+}
+#endif
+/* Property dialogs: */
+/**
+ * docbook_generic_node_properties_factory_method:
  * @custom_property_dialog:
  * @doc:
  * @node:
@@ -1443,7 +1728,9 @@ docbook_print_method_action_callback (CongServicePrintMethod *print_method,
  * Returns:
  */
 GtkWidget* 
-docbook_generic_node_factory_method(CongServiceNodePropertyDialog *custom_property_dialog, CongDocument *doc, CongNodePtr node)
+docbook_generic_node_properties_factory_method (CongServiceNodePropertyDialog *custom_property_dialog, 
+						CongDocument *doc, 
+						CongNodePtr node)
 {
 	gchar* glade_filename;
 	GladeXML *xml;
@@ -1592,29 +1879,6 @@ docbook_orderedlist_properties_factory_method(CongServiceNodePropertyDialog *cus
 	return glade_xml_get_widget(xml, "common_dialog");
 }
 
-static void
-open_ulink_in_browser (CongNodePtr node)
-{
-	gchar *url = cong_node_get_attribute (node, NULL, "url");
-
-	if (url) {	
-		/* FIXME: should we have some error handling? */
-		gnome_url_show (url,
-				NULL);
-	}
-
-	g_free (url);
-}
-
-static void
-on_test_link_pressed (GtkButton *button,
-		      gpointer user_data)
-{
-	CongNodePtr node = user_data;
-
-	open_ulink_in_browser (node);
-}
-
 /**
  * docbook_ulink_properties_factory_method:
  * @custom_property_dialog:
@@ -1873,11 +2137,43 @@ plugin_docbook_plugin_register(CongPlugin *plugin)
 					  NULL);
 #endif
 
+	/* Property pages: */
+#if 1
+	cong_plugin_register_custom_property_page (plugin,
+						    _("Scope"), 
+						    _("Provides a Scope properties page for most DocBook nodes"),
+						    "docbook-scope-property_page",
+						    docbook_node_page_factory_method_scope,
+						    NULL);
+	cong_plugin_register_custom_property_page (plugin,
+						    _("Language"), 
+						    _("Provides a Language properties page for most DocBook nodes"),
+						    "docbook-language-property_page",
+						    docbook_node_page_factory_method_language,
+						    NULL);
+	cong_plugin_register_custom_property_page (plugin,
+						    _("Revisions"), 
+						    _("Provides a Revisions properties page for most DocBook nodes"),
+						    "docbook-revisions-property_page",
+						    docbook_node_page_factory_method_revisions,
+						    NULL);
+	cong_plugin_register_custom_property_page_for_element (plugin,
+							       "List",
+							       "docbook-orderedlist-properties",
+							       docbook_orderedlist_page_factory_method,
+							       NULL);
+#endif
+	cong_plugin_register_custom_property_page_for_element (plugin,
+							       "Link",
+							       "docbook-ulink-properties",
+							       docbook_ulink_page_factory_method,
+							       NULL);
+	/* Property dialogs: */
 	cong_plugin_register_custom_property_dialog(plugin,
 						    _("Generic DocBook property dialog"), 
 						    _("Provides a Properties dialog for most DocBook nodes"),
 						    "docbook-generic-node-properties",
-						    docbook_generic_node_factory_method,
+						    docbook_generic_node_properties_factory_method,
 						    NULL);
 
 	cong_plugin_register_custom_property_dialog_for_element (plugin,
