@@ -5,7 +5,7 @@
  *
  * Empty plugin, for use as a template
  *
- * Copyright (C) 2003 David Malcolm
+ * Copyright (C) 2004 David Malcolm
  *
  * Conglomerate is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,20 +29,36 @@
 
 #include "cong-fake-plugin-hooks.h"
 
- /* would be exposed as "plugin_register"? */
-gboolean plugin_empty_plugin_register(CongPlugin *plugin)
+/* would be exposed as "plugin_register"? */
+/**
+ * plugin_empty_plugin_register:
+ * @plugin:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+plugin_empty_plugin_register (CongPlugin *plugin)
 {
-	g_return_val_if_fail(plugin, FALSE);
+	g_return_val_if_fail (IS_CONG_PLUGIN (plugin), FALSE);
 
-	/* Register your service here */
+	/* Register your services here: */
 	
 	return TRUE;
 }
 
 /* exposed as "plugin_configure"? legitimate for it not to be present */
-gboolean plugin_empty_plugin_configure(CongPlugin *plugin)
+/**
+ * plugin_empty_plugin_configure:
+ * @plugin:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+plugin_empty_plugin_configure (CongPlugin *plugin)
 {
-	g_return_val_if_fail(plugin, FALSE);
+	g_return_val_if_fail (IS_CONG_PLUGIN (plugin), FALSE);
 
 	return TRUE;
 }
